==> passbase_flutter-2.11.0.tar.gz: android/src/main/kotlin/passbaseplugin/pettersonapps/com/passbase_flutter/PassbaseFlutterPlugin.kt <==
package passbaseplugin.pettersonapps.com.passbase_flutter

import android.app.Activity
import android.content.Context
import android.view.View
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar
import com.passbase.passbase_sdk.PassbaseSDK
import com.passbase.passbase_sdk.PassbaseButton
import com.passbase.passbase_sdk.PassbaseSDKListener
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.StandardMessageCodec
import io.flutter.plugin.platform.PlatformView
import io.flutter.plugin.platform.PlatformViewFactory
import io.flutter.plugin.platform.PlatformViewRegistry

class PassbaseFlutterPlugin : MethodCallHandler, FlutterPlugin, ActivityAware {

    private lateinit var channel: MethodChannel
    private lateinit var passbase: PassbaseSDK
    private lateinit var platformViewRegistry: PlatformViewRegistry

    companion object {
        @JvmStatic
        fun registerWith(registrar: Registrar) {
            val plugin = PassbaseFlutterPlugin()
            plugin.passbase = PassbaseSDK(registrar.activity())
            plugin.channel = MethodChannel(registrar.messenger(), "passbase_flutter")
            plugin.channel.setMethodCallHandler(plugin)
            PassbaseButtonPlugin.registerWith(registrar.activity(), plugin.passbase, plugin.channel, registrar.platformViewRegistry())
        }
    }

    override fun onMethodCall(call: MethodCall, result: Result) {
        when (call.method) {
            "initialize" -> {
                PassbaseSDK.source = 3
                passbase.initialize(call.arguments as String)

                result.success(null)
            }
            "startVerification" -> {
                passbase.callback(object : PassbaseSDKListener {
                    override fun onStart() {
                        channel.invokeMethod("verification_start", "Verification started")
                    }

                    override fun onFinish(identityAccessKey: String) {
                        channel.invokeMethod("verification_complete", identityAccessKey)
                    }

                    override fun onError(errorCode: String) {
                        channel.invokeMethod("verification_error", errorCode)
                    }

                    override fun onSubmitted(identityAccessKey: String) {
                        channel.invokeMethod("verification_submitted", identityAccessKey)
                    }
                })

                passbase.startVerification()
            }
            "setPrefillUserEmail" -> {
                passbase.prefillUserEmail = call.arguments as String?
            }
            "setMetaData" -> {
                passbase.metaData = call.arguments as String?
            }
            "setPrefillCountry" -> {
                passbase.prefillCountry = call.arguments as String?
            }
            else -> {
                result.notImplemented()
            }
        }
    }

    override fun onAttachedToEngine(binding: FlutterPlugin.FlutterPluginBinding) {
        channel = MethodChannel(binding.binaryMessenger, "passbase_flutter")
        platformViewRegistry = binding.platformViewRegistry
        channel.setMethodCallHandler(this)
    }

    override fun onDetachedFromEngine(binding: FlutterPlugin.FlutterPluginBinding) {
        channel.setMethodCallHandler(null)
    }

    override fun onAttachedToActivity(binding: ActivityPluginBinding) {
        val activity = binding.activity;
        passbase = PassbaseSDK(activity)
        PassbaseButtonPlugin.registerWith(activity, passbase, channel, platformViewRegistry)
    }

    override fun onDetachedFromActivityForConfigChanges() {
    }

    override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
    }

    override fun onDetachedFromActivity() {
    }
}

object PassbaseButtonPlugin {
    fun registerWith(activity: Activity, passbase: PassbaseSDK, channel: MethodChannel, platformViewRegistry: PlatformViewRegistry) {
        val viewFactory = PassbaseButtonFactory(activity, passbase, channel)
        platformViewRegistry.registerViewFactory("PassbaseButton", viewFactory)
    }
}

class PassbaseButtonFactory(private val activity: Activity, private val passbase: PassbaseSDK, private val channel: MethodChannel) :
        PlatformViewFactory(StandardMessageCodec.INSTANCE) {

    override fun create(context: Context,
                        id: Int,
                        args: Any?): PlatformView {
        return PassbaseButtonContainer(
                activity as Context,
                passbase,
                channel
        )
    }
}

class PassbaseButtonContainer internal constructor(context: Context, private val passbase: PassbaseSDK, private val channel: MethodChannel) : PlatformView {
    private val passbaseButton: PassbaseButton = PassbaseButton(context = context)

    init {
        passbaseButton.setOnClickListener {
            passbase.callback(object : PassbaseSDKListener {
                override fun onStart() {
                    channel.invokeMethod("verification_start", "Verification started")
                }

                override fun onFinish(identityAccessKey: String) {
                    channel.invokeMethod("verification_complete", identityAccessKey)
                }

                override fun onError(errorCode: String) {
                    channel.invokeMethod("verification_error", errorCode)
                }

                override fun onSubmitted(identityAccessKey: String) {
                    channel.invokeMethod("verification_submitted", identityAccessKey)
                }
            })
            passbase.startVerification()
        }
    }

    override fun dispose() {
    }

    override fun getView(): View {
        return passbaseButton
    }
}

==> passbase_flutter-2.13.4.tar.gz: android/src/main/kotlin/passbaseplugin/pettersonapps/com/passbase_flutter/PassbaseFlutterPlugin.kt <==
package passbaseplugin.pettersonapps.com.passbase_flutter

import android.app.Activity
import android.content.Context
import android.view.View
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar
import com.passbase.passbase_sdk.PassbaseSDK
import com.passbase.passbase_sdk.PassbaseButton
import com.passbase.passbase_sdk.PassbaseSDKListener
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.StandardMessageCodec
import io.flutter.plugin.platform.PlatformView
import io.flutter.plugin.platform.PlatformViewFactory
import io.flutter.plugin.platform.PlatformViewRegistry

class PassbaseFlutterPlugin : MethodCallHandler, FlutterPlugin, ActivityAware {

    private lateinit var channel: MethodChannel
    private lateinit var passbase: PassbaseSDK
    private lateinit var platformViewRegistry: PlatformViewRegistry

    companion object {
        @JvmStatic
        fun registerWith(registrar: Registrar) {
            val plugin = PassbaseFlutterPlugin()
            plugin.passbase = PassbaseSDK(registrar.activity()!!)
            plugin.channel = MethodChannel(registrar.messenger(), "passbase_flutter")
            plugin.channel.setMethodCallHandler(plugin)
            PassbaseButtonPlugin.registerWith(registrar.activity()!!, plugin.passbase, plugin.channel, registrar.platformViewRegistry())
        }
    }

    override fun onMethodCall(call: MethodCall, result: Result) {
        when (call.method) {
            "initialize" -> {
                PassbaseSDK.source = 3
                passbase.initialize(call.arguments as String)

                result.success(null)
            }
            "startVerification" -> {
                passbase.callback(object : PassbaseSDKListener {
                    override fun onStart() {
                        channel.invokeMethod("verification_start", "Verification started")
                    }

                    override fun onFinish(identityAccessKey: String) {
                        channel.invokeMethod("verification_complete", identityAccessKey)
                    }

                    override fun onError(errorCode: String) {
                        channel.invokeMethod("verification_error", errorCode)
                    }

                    override fun onSubmitted(identityAccessKey: String) {
                        channel.invokeMethod("verification_submitted", identityAccessKey)
                    }
                })

                passbase.startVerification()
            }
            "setPrefillUserEmail" -> {
                passbase.prefillUserEmail = call.arguments as String?
            }
            "setMetaData" -> {
                passbase.metaData = call.arguments as String?
            }
            "setPrefillCountry" -> {
                passbase.prefillCountry = call.arguments as String?
            }
            else -> {
                result.notImplemented()
            }
        }
    }

    override fun onAttachedToEngine(binding: FlutterPlugin.FlutterPluginBinding) {
        channel = MethodChannel(binding.binaryMessenger, "passbase_flutter")
        platformViewRegistry = binding.platformViewRegistry
        channel.setMethodCallHandler(this)
    }

    override fun onDetachedFromEngine(binding: FlutterPlugin.FlutterPluginBinding) {
        channel.setMethodCallHandler(null)
    }

    override fun onAttachedToActivity(binding: ActivityPluginBinding) {
        val activity = binding.activity;
        passbase = PassbaseSDK(activity)
        PassbaseButtonPlugin.registerWith(activity, passbase, channel, platformViewRegistry)
    }

    override fun onDetachedFromActivityForConfigChanges() {
    }

    override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
    }

    override fun onDetachedFromActivity() {
    }
}

object PassbaseButtonPlugin {
    fun registerWith(activity: Activity, passbase: PassbaseSDK, channel: MethodChannel, platformViewRegistry: PlatformViewRegistry) {
        val viewFactory = PassbaseButtonFactory(activity, passbase, channel)
        platformViewRegistry.registerViewFactory("PassbaseButton", viewFactory)
    }
}

class PassbaseButtonFactory(private val activity: Activity, private val passbase: PassbaseSDK, private val channel: MethodChannel) :
        PlatformViewFactory(StandardMessageCodec.INSTANCE) {

    override fun create(context: Context?,
                        viewId: Int,
                        args: Any?): PlatformView {
        return PassbaseButtonContainer(
                activity as Context,
                passbase,
                channel
        )
    }
}

class PassbaseButtonContainer internal constructor(context: Context, private val passbase: PassbaseSDK, private val channel: MethodChannel) : PlatformView {
    private val passbaseButton: PassbaseButton = PassbaseButton(context = context)

    init {
        passbaseButton.setOnClickListener {
            passbase.callback(object : PassbaseSDKListener {
                override fun onStart() {
                    channel.invokeMethod("verification_start", "Verification started")
                }

                override fun onFinish(identityAccessKey: String) {
                    channel.invokeMethod("verification_complete", identityAccessKey)
                }

                override fun onError(errorCode: String) {
                    channel.invokeMethod("verification_error", errorCode)
                }

                override fun onSubmitted(identityAccessKey: String) {
                    channel.invokeMethod("verification_submitted", identityAccessKey)
                }
            })
            passbase.startVerification()
        }
    }

    override fun dispose() {
    }

    override fun getView(): View {
        return passbaseButton
    }
}
